@@ -3,6 +3,7 @@ Low-level LDAP hooks.
 """
 
 import ldap3
+import logging
 
 from contextlib import contextmanager
 
@@ -12,6 +13,9 @@ from django_python3_ldap.conf import settings
 from django_python3_ldap.utils import import_func, format_search_filter
 
 
+logger = logging.getLogger(__name__)
+
+
 class Connection(object):
 
     """
@@ -68,6 +72,7 @@ class Connection(object):
             search_filter = format_search_filter({}),
             search_scope = ldap3.SEARCH_SCOPE_WHOLE_SUBTREE,
             attributes = ldap3.ALL_ATTRIBUTES,
+            get_operational_attributes = True,
             paged_size = 30,
         )
         return (
@@ -106,23 +111,30 @@ def connection(**kwargs):
     in settings.LDAP_AUTH_USER_LOOKUP_FIELDS, plus a `password` argument.
     """
     # Format the DN for the username.
+    kwargs = {
+        key: value
+        for key, value
+        in kwargs.items()
+        if value
+    }
     username = None
     password = None
     if kwargs:
         password = kwargs.pop("password")
         username = import_func(settings.LDAP_AUTH_FORMAT_USERNAME)(kwargs)
     # Make the connection.
-    if username or password:
-        if settings.LDAP_AUTH_USE_TLS:
-            auto_bind = ldap3.AUTO_BIND_TLS_BEFORE_BIND
-        else:
-            auto_bind = ldap3.AUTO_BIND_NO_TLS
+    if settings.LDAP_AUTH_USE_TLS:
+        auto_bind = ldap3.AUTO_BIND_TLS_BEFORE_BIND
     else:
-        auto_bind = ldap3.AUTO_BIND_NONE
+        auto_bind = ldap3.AUTO_BIND_NO_TLS
     try:
         with ldap3.Connection(ldap3.Server(settings.LDAP_AUTH_URL), user=username, password=password, auto_bind=auto_bind) as c:
             yield Connection(c)
-    except (ldap3.LDAPBindError, ldap3.LDAPSASLPrepError):
+    except ldap3.LDAPBindError as ex:
+        logger.info("LDAP login failed: {ex}".format(ex=ex))
+        yield None
+    except ldap3.LDAPException as ex:
+        logger.warn("LDAP connect failed: {ex}".format(ex=ex))
         yield None
 
 
